@@ -26,21 +26,12 @@ class UserSingle7 extends UserSingleBase {
     unset($userinfo['block']);
     unset($userinfo['form_build_id']);
     foreach (array('created', 'access', 'login') as $key) {
-      $userinfo['user_' . $key] = format_date($userinfo[$key]);
+      $userinfo['user_' . $key] = drush_format_date($userinfo[$key]);
     }
     $userinfo['user_status'] = $userinfo['status'] ? 'active' : 'blocked';
     return $userinfo;
   }
 
-  public function passResetUrl($path = '') {
-    $options = array();
-    if ($path) {
-      $options['query']['destination'] = $path;
-    }
-    // D6,D7 append a /login. Otherwise identical to D8+.
-    return drush_url(user_pass_reset_url($this->account) . '/login', $options);
-  }
-
   function password($pass) {
     user_save($this->account, array('pass' => $pass));
   }
